@@ -1,5 +1,6 @@
 from mockups.helpers import *
 from mockups.factory import Factory
-from mockups.base import ModelMockup
+from mockups.base import Mockup
+from mockups.base import Mockup as MockupModel # compat
 from mockups.constraints import InvalidConstraint
 
