@@ -35,15 +35,21 @@ class GeneratorException(Exception):
     pass
 
 
+class IGNORE_EMPTY(object):
+    pass
+
+
 class Generator(object):
     coerce_type = staticmethod(lambda x: x)
     empty_value = None
     empty_p = 0
 
-    def __init__(self, empty_p=None, coerce=None):
+    def __init__(self, empty_p=None, empty_value=IGNORE_EMPTY, coerce=None):
         if empty_p is not None:
             self.empty_p = empty_p
-        if coerce:
+        if empty_value is not IGNORE_EMPTY:
+            self.empty_value = empty_value
+        if coerce is not None:
             self.coerce_type = coerce
 
     def coerce(self, value):
@@ -159,12 +165,15 @@ class LoremGenerator(Generator):
             lorem = lorem[:max(1, length)]
         return lorem.strip()
 
+
 class LoremSentenceGenerator(LoremGenerator):
     method = 's'
 
+
 class LoremHTMLGenerator(LoremGenerator):
     method = 'p'
 
+
 class LoremWordGenerator(LoremGenerator):
     count = 7
     method = 'w'
@@ -200,31 +209,24 @@ class PositiveSmallIntegerGenerator(SmallIntegerGenerator):
     min_value = 0
 
 
-class ChoicesGenerator(Generator):
-    def __init__(self, choices=(), values=(), *args, **kwargs):
-        assert len(choices) or len(values)
-        self.choices = list(choices)
-        if not values:
-            self.values = [k for k, v in self.choices]
-        else:
-            self.values = list(values)
-        super(ChoicesGenerator, self).__init__(*args, **kwargs)
+class ChoiceGenerator(Generator):
+    choices = []
+
+    def __init__(self, choices=None, *args, **kwargs):
+        if choices is not None:
+            self.choices = choices
+        super(ChoiceGenerator, self).__init__(*args, **kwargs)
 
     def generate(self):
-        return random.choice(self.values)
+        return random.choice(self.choices)
 
 
-class BooleanGenerator(ChoicesGenerator):
-    def __init__(self, none=False, *args, **kwargs):
-        values = (True, False)
-        if none:
-            values = values + (None,)
-        super(BooleanGenerator, self).__init__(values=values, *args, **kwargs)
+class BooleanGenerator(ChoiceGenerator):
+    choices = (True, False)
 
 
 class NullBooleanGenerator(BooleanGenerator):
-    def __init__(self, none=True, *args, **kwargs):
-        super(NullBooleanGenerator, self).__init__(none=none, *args, **kwargs)
+    empty_p = 1 / 3.0
 
 
 class DateTimeGenerator(Generator):
@@ -357,13 +359,12 @@ class IPAddressGenerator(Generator):
 
 
 class TimeGenerator(Generator):
-    coerce_type = unicode
-
     def generate(self):
-        return u'%02d:%02d:%02d' % (
+        return datetime.time(
             random.randint(0,23),
             random.randint(0,59),
             random.randint(0,59),
+            random.randint(0, 999999),
         )
 
 
@@ -418,6 +419,7 @@ class MediaFilePathGenerator(FilePathGenerator):
         filename = relpath(filename, settings.MEDIA_ROOT)
         return filename
 
+
 # TODO: try to get this thing out of here
 class InstanceGenerator(Generator):
     '''
@@ -510,6 +512,11 @@ class FieldGenerator(Generator):
         return self._generator.generate()
 
 
+class ChoiceFieldGenerator(FieldGenerator):
+    def get_generator(self, field, *args, **kwargs):
+        return ChoiceGenerator([k for k, v in field.choices])
+
+
 class ForeignKeyFieldGenerator(FieldGenerator):
     def get_generator(self, field, generate_fk=None, follow_fk=None, **kwargs):
         # if generate_fk is set, follow_fk is ignored.
@@ -603,4 +610,3 @@ class BigIntegerFieldGenerator(FieldGenerator):
         return IntegerGenerator(min_value=-field.MAX_BIGINT - 1,
                 max_value=field.MAX_BIGINT)
 
-
